CascadeAngleControlData

Struct CascadeAngleControlData 

pub struct CascadeAngleControlData<T> {
    pub measurement: T,
    pub prev_measurement: T,
    pub rate: T,
    pub dt: T,
    pub integral_limit: T,
    pub reset_integral: bool,
}
Control data for angle-based PID stabilization callback.

Fields

measurement: T

The current measured angle, calculated from sensors.

prev_measurement: T

The prevously measured angle, calculated from sensors.

rate: T

The current rate of change, typically reported by a gyro.

dt: T

The time delta since the last computation.

integral_limit: T

The maximum allowed value for the integral term, used to prevent integral windup.

reset_integral: bool

Flag to reset the integral term, typically used when the controller is inactive.